InMemoryAlphaXFileTarget class final

In-memory target for file-download tests.

Constructors

InMemoryAlphaXFileTarget({String? name = 'memory.bin'})
Creates an empty target.

Properties

bytes List<int>
Bytes written after a successful close.
no setter
hashCode int
The hash code for this object.
no setterinherited
name String?
Optional display name of the destination.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openWrite() Future<AlphaXFileSink>
Opens a destination sink. The transport closes or aborts the sink.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited